@@ -4,8 +4,6 @@
 # Use of this source code is governed by a BSD-style
 # license that can be found in the LICENSE file.
 
-import sys
-
 try:
     from httplib import HTTPException
 except ImportError:
@@ -70,7 +68,7 @@ def get_driver(driver, retry_count=3, *args, **kwargs):
     raise err
 
 
-def Browser(driver_name="firefox", retry_count=3, *args, **kwargs):
+def Browser(driver_name="firefox", retry_count=3, *args, **kwargs):  # NOQA: N802
     """
     Returns a driver instance for the given name.
 
@@ -89,4 +87,4 @@ def Browser(driver_name="firefox", retry_count=3, *args, **kwargs):
     except KeyError:
         raise DriverNotFoundError("No driver for %s" % driver_name)
 
-    return get_driver(driver, *args, **kwargs)
+    return get_driver(driver, retry_count=retry_count, *args, **kwargs)
