@@ -22,6 +22,9 @@ class CookieManagerAPI(InheritedDocs("_CookieManagerAPI", (object,), {})):
         >>> assert cookie_manager['name'] == 'Tony'
     """
 
+    def __init__(self, driver):
+        self.driver = driver
+
     def add(self, cookies):
         """
         Adds a cookie.
@@ -51,6 +54,12 @@ class CookieManagerAPI(InheritedDocs("_CookieManagerAPI", (object,), {})):
         """
         raise NotImplementedError
 
+    def delete_all(self):
+        """
+        Delete all cookies.
+        """
+        raise NotImplementedError
+
     def all(self, verbose=False):
         """
         Returns all of the cookies.
