@@ -69,6 +69,14 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
         """
         raise NotImplementedError("%s doesn't visit any url." % self.driver_name)
 
+    def new_tab(self, url):
+        """
+        Visits a given URL in a new tab.
+
+        The ``url`` parameter is a string.
+        """
+        raise NotImplementedError("%s doesn't open a new tab." % self.driver_name)
+
     def back(self):
         """
         Back to the last URL in the browsing history.
@@ -305,6 +313,12 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
         radio and select.
 
         Checkboxes should be specified as a boolean in the dict.
+
+        Arguments:
+            field_values (dict): Values for all the fields in the form, in the pattern of {field name: field value}
+            form_id (str): Id of the form to fill. Can be used instead of name.
+            name (str): Name of the form to fill.
+            ignore_missing (bool): Ignore missing keys in the dict.
         """
         raise NotImplementedError(
             "%s doesn't support filling forms with a dict." % self.driver_name
