@@ -4,12 +4,13 @@
 # Use of this source code is governed by a BSD-style
 # license that can be found in the LICENSE file.
 
-from __future__ import with_statement
 import os.path
 import re
 import time
 import sys
 
+import six
+
 import lxml.etree
 import lxml.html
 from lxml.cssselect import CSSSelector
@@ -64,7 +65,7 @@ class LxmlDriver(ElementPresentMixIn, DriverAPI):
                 continue
 
             if isinstance(v, lxml.html.MultipleSelectOptions):
-                data[k] = [val for val in v]
+                data[k] = list(v)
             else:
                 data[k] = v
 
@@ -239,7 +240,7 @@ class LxmlDriver(ElementPresentMixIn, DriverAPI):
     def fill(self, name, value):
         self.find_by_name(name=name).first.fill(value)
 
-    def fill_form(self, field_values, form_id=None, name=None):
+    def fill_form(self, field_values, form_id=None, name=None, ignore_missing=False):
         form = None
 
         if name is not None:
@@ -248,30 +249,34 @@ class LxmlDriver(ElementPresentMixIn, DriverAPI):
             form = self.find_by_id(form_id)
 
         for name, value in field_values.items():
-            if form:
-                element = form.find_by_name(name)
-                control = element.first._element
-            else:
-                element = self.find_by_name(name)
-                control = element.first._control
-            control_type = control.get("type")
-            if control_type == "checkbox":
-                if value:
-                    control.value = value  # control.options
+            try:
+                if form:
+                    element = form.find_by_name(name)
+                    control = element.first._element
                 else:
-                    control.value = []
-            elif control_type == "radio":
-                control.value = (
-                    value
-                )  # [option for option in control.options if option == value]
-            elif control_type == "select":
-                if isinstance(value, list):
+                    element = self.find_by_name(name)
+                    control = element.first._control
+                control_type = control.get("type")
+                if control_type == "checkbox":
+                    if value:
+                        control.value = value  # control.options
+                    else:
+                        control.value = []
+                elif control_type == "radio":
+                    control.value = (
+                        value
+                    )  # [option for option in control.options if option == value]
+                elif control_type == "select":
+                    if isinstance(value, list):
+                        control.value = value
+                    else:
+                        control.value = [value]
+                else:
+                    # text, textarea, password, tel
                     control.value = value
-                else:
-                    control.value = [value]
-            else:
-                # text, textarea, password, tel
-                control.value = value
+            except ElementDoesNotExist as e:
+                if not ignore_missing:
+                    raise ElementDoesNotExist(e)
 
     def choose(self, name, value):
         self.find_by_name(name).first._control.value = value
@@ -443,12 +448,12 @@ class LxmlControlElement(LxmlElement):
 
     def fill(self, value):
         parent_form = self._get_parent_form()
-        if sys.version_info[0] > 2:
-            parent_form.fields[self["name"]] = value
-        else:
-            if not isinstance(value, unicode):
+
+        if not sys.version_info[0] > 2:
+            if not isinstance(value, six.text_type):
                 value = value.decode("utf-8")
-            parent_form.fields[self["name"]] = value
+
+        parent_form.fields[self["name"]] = value
 
     def select(self, value):
         self._control.value = value
