@@ -23,7 +23,7 @@ from selenium.common.exceptions import (
     MoveTargetOutOfBoundsException,
 )
 from selenium.webdriver.common.action_chains import ActionChains
-from selenium.webdriver.support import expected_conditions as EC
+from selenium.webdriver.support import expected_conditions as EC  # NOQA: N812
 from selenium.webdriver.support.ui import WebDriverWait
 
 from six import BytesIO
@@ -33,6 +33,8 @@ from splinter.driver.find_links import FindLinks
 from splinter.driver.xpath_utils import _concat_xpath_from_str
 from splinter.element_list import ElementList
 
+from splinter.exceptions import ElementDoesNotExist
+
 
 if sys.version_info[0] > 2:
     _meth_func = "__func__"
@@ -41,19 +43,22 @@ else:
     _meth_func = "im_func"
     _func_name = "func_name"
 
+
 # Patch contextmanager onto Selenium's Alert
 def alert_enter(self):
     return self
 
+
 def alert_exit(self, type, value, traceback):
     pass
 
+
 Alert.__enter__ = alert_enter
 Alert.__exit__ = alert_exit
 Alert.fill_with = Alert.send_keys
 
 
-class switch_window:
+class switch_window:  # NOQA: N801
     def __init__(self, browser, window_handle):
         self.browser = browser
         self.window_handle = window_handle
@@ -121,6 +126,29 @@ class Window(object):
 
     is_current = property(**is_current())
 
+    def new_tab(self, url):
+        """ Open new tab in current window """
+        if self._browser.driver.name == 'firefox':
+            self._browser.driver.get('about:config')
+            self._browser.driver.execute_script('document.getElementById("warningButton").click();')
+            self._browser.driver.execute_script(
+                """
+                Components.classes['@mozilla.org/preferences-service;1']
+                    .getService(Components.interfaces.nsIPrefBranch)
+                    .setIntPref('browser.link.open_newwindow', 3);
+                """)
+
+        self._browser.driver.execute_script("window.open('%s', '_blank');" % url)
+
+        if self._browser.driver.name == 'firefox':
+            self._browser.driver.execute_script(
+                """
+                Components.classes['@mozilla.org/preferences-service;1']
+                    .getService(Components.interfaces.nsIPrefBranch)
+                    .setIntPref('browser.link.open_newwindow', 2);
+                """)
+            self._browser.driver.back()
+
     def close(self):
         """ Close this window. If this window is active, switch to previous window """
         target = self.prev if (self.is_current and self.prev != self) else None
@@ -221,6 +249,7 @@ def _find(self, finder, selector):
 
     return elem_list
 
+
 def find_by(self, finder, selector, original_find=None, original_query=None, wait_time=None):
     """Wrapper for finding elements.
 
@@ -233,7 +262,7 @@ def find_by(self, finder, selector, original_find=None, original_query=None, wai
     elem_list = []
 
     func_name = getattr(getattr(finder, _meth_func), _func_name)
-    find_by = original_find or func_name[func_name.rfind("_by_") + 4 :]
+    find_by = original_find or func_name[func_name.rfind("_by_") + 4:]
     query = original_query or selector
 
     # Zero second wait time means only check once
@@ -534,7 +563,7 @@ class BaseWebDriver(DriverAPI):
             self.driver.find_elements_by_tag_name,
             tag,
             wait_time=wait_time,
-    )
+        )
 
     def find_by_value(self, value, wait_time=None):
         elem = self.find_by_xpath(
@@ -569,7 +598,7 @@ class BaseWebDriver(DriverAPI):
 
     attach_file = fill
 
-    def fill_form(self, field_values, form_id=None, name=None):
+    def fill_form(self, field_values, form_id=None, name=None, ignore_missing=False):
         form = None
 
         if name is not None:
@@ -578,29 +607,33 @@ class BaseWebDriver(DriverAPI):
             form = self.find_by_id(form_id)
 
         for name, value in field_values.items():
-            if form:
-                elements = form.find_by_name(name)
-            else:
-                elements = self.find_by_name(name)
-            element = elements.first
-            if (
-                element["type"] in ["text", "password", "tel"]
-                or element.tag_name == "textarea"
-            ):
-                element.value = value
-            elif element["type"] == "checkbox":
-                if value:
-                    element.check()
+            try:
+                if form:
+                    elements = form.find_by_name(name)
                 else:
-                    element.uncheck()
-            elif element["type"] == "radio":
-                for field in elements:
-                    if field.value == value:
-                        field.click()
-            elif element._element.tag_name == "select":
-                element.select(value)
-            else:
-                element.value = value
+                    elements = self.find_by_name(name)
+                element = elements.first
+                if (
+                    element["type"] in ["text", "password", "tel"]
+                    or element.tag_name == "textarea"
+                ):
+                    element.value = value
+                elif element["type"] == "checkbox":
+                    if value:
+                        element.check()
+                    else:
+                        element.uncheck()
+                elif element["type"] == "radio":
+                    for field in elements:
+                        if field.value == value:
+                            field.click()
+                elif element._element.tag_name == "select":
+                    element.select(value)
+                else:
+                    element.value = value
+            except ElementDoesNotExist as e:
+                if not ignore_missing:
+                    raise ElementDoesNotExist(e)
 
     def type(self, name, value, slowly=False):
         element = self.find_by_name(name).first._element
@@ -732,10 +765,14 @@ class WebDriverElement(ElementAPI):
 
     def clear(self):
         if self._element.get_attribute("type") in [
-            "textarea",
-            "text",
+            "email",
+            "number",
             "password",
+            "search",
             "tel",
+            "text",
+            "textarea",
+            "url",
         ]:
             self._element.clear()
 
@@ -934,7 +971,7 @@ class WebDriverElement(ElementAPI):
         self.scroll_to()
         ActionChains(self.driver).drag_and_drop(self._element, droppable._element).perform()
 
-    def _full_screen():
+    def _full_screen(self):
         width = self.driver.execute_script("return Math.max(document.body.scrollWidth, document.body.offsetWidth);")
         height = self.driver.execute_script("return Math.max(document.body.scrollHeight, document.body.offsetHeight);")
         self.driver.set_window_size(width, height)
