@@ -12,17 +12,21 @@ if sys.version_info[0] > 2:
 else:
     from urlparse import urlparse  # NOQA
 
+import warnings
+
 
 class CookieManager(CookieManagerAPI):
-    def __init__(self, driver):
-        self.driver = driver
-
     def add(self, cookies):
         if isinstance(cookies, list):
+            warnings.warn(
+                'Using a list of cookies is deprecated.'
+                ' Version 0.16.0 will only accept one cookie at a time.',
+                FutureWarning,
+            )
             for cookie in cookies:
                 for key, value in cookie.items():
                     self.driver.add_cookie({"name": key, "value": value})
-                return
+            return
         for key, value in cookies.items():
             self.driver.add_cookie({"name": key, "value": value})
 
@@ -31,7 +35,10 @@ class CookieManager(CookieManagerAPI):
             for cookie in cookies:
                 self.driver.delete_cookie(cookie)
         else:
-            self.driver.delete_all_cookies()
+            self.delete_all()
+
+    def delete_all(self):
+        self.driver.delete_all_cookies()
 
     def all(self, verbose=False):
         if not verbose:
