@@ -9,10 +9,11 @@ from __future__ import unicode_literals
 import mimetypes
 import re
 import time
+import warnings
 
 import lxml.html
 from lxml.cssselect import CSSSelector
-from zope.testbrowser.browser import Browser, ListControl, SubmitControl
+from zope.testbrowser.browser import Browser, ListControl
 from splinter.element_list import ElementList
 from splinter.exceptions import ElementDoesNotExist
 from splinter.driver import DriverAPI, ElementAPI
@@ -23,15 +24,17 @@ from splinter.cookie_manager import CookieManagerAPI
 
 
 class CookieManager(CookieManagerAPI):
-    def __init__(self, driver):
-        self.driver = driver
-
     def add(self, cookies):
         if isinstance(cookies, list):
+            warnings.warn(
+                'Using a list of cookies is deprecated.'
+                ' Version 0.16.0 will only accept one cookie at a time.',
+                FutureWarning,
+            )
             for cookie in cookies:
                 for key, value in cookie.items():
                     self.driver.cookies[key] = value
-                return
+            return
         for key, value in cookies.items():
             self.driver.cookies[key] = value
 
@@ -43,7 +46,10 @@ class CookieManager(CookieManagerAPI):
                 except KeyError:
                     pass
         else:
-            self.driver.cookies.clearAll()
+            self.delete_all()
+
+    def delete_all(self):
+        self.driver.cookies.clearAll()
 
     def all(self, verbose=False):
         cookies = {}
@@ -233,27 +239,31 @@ class ZopeTestBrowser(ElementPresentMixIn, DriverAPI):
     def fill(self, name, value):
         self.find_by_name(name=name).first._control.value = value
 
-    def fill_form(self, field_values, form_id=None, name=None):
+    def fill_form(self, field_values, form_id=None, name=None, ignore_missing=False):
         form = self._browser
         if name or form_id:
             form = self._browser.getForm(name=name, id=form_id)
 
         for name, value in field_values.items():
-            control = form.getControl(name=name)
+            try:
+                control = form.getControl(name=name)
 
-            if control.type == "checkbox":
-                if value:
-                    control.value = control.options
+                if control.type == "checkbox":
+                    if value:
+                        control.value = control.options
+                    else:
+                        control.value = []
+                elif control.type == "radio":
+                    control.value = [
+                        option for option in control.options if option == value
+                    ]
+                elif control.type == "select":
+                    control.value = [value]
                 else:
-                    control.value = []
-            elif control.type == "radio":
-                control.value = [
-                    option for option in control.options if option == value
-                ]
-            elif control.type == "select":
-                control.value = [value]
-            else:
-                control.value = value
+                    control.value = value
+            except NotImplementedError as e:
+                if not ignore_missing:
+                    raise NotImplementedError(e)
 
     def choose(self, name, value):
         control = self._browser.getControl(name=name)
